@@ -20,6 +20,9 @@
 #include "settings.h"
 
 #include <QDebug>
+#include <QStandardPaths>
+#include <QSettings>
+#include <QFile>
 
 Settings::Settings(QObject *parent)
     : QObject(parent)
@@ -27,8 +30,19 @@ Settings::Settings(QObject *parent)
 #if defined(Q_OS_IOS) || defined(Q_OS_ANDROID) || defined(Q_OS_BLACKBERRY) || defined(Q_OS_QNX) || defined(Q_OS_WINRT)
     m_mobile = true;
 #else
-    m_mobile = qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE");
+    m_mobile = qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE") &&
+        (QString::fromLatin1(qgetenv("QT_QUICK_CONTROLS_MOBILE")) == QStringLiteral("1") ||
+         QString::fromLatin1(qgetenv("QT_QUICK_CONTROLS_MOBILE")) == QStringLiteral("true"));
 #endif
+
+    const QString configPath = QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral("kdeglobals"));
+    if (QFile::exists(configPath)) {
+        QSettings globals(configPath, QSettings::IniFormat);
+        globals.beginGroup(QStringLiteral("KDE"));
+        m_scrollLines = qMax(1, globals.value(QStringLiteral("WheelScrollLines"), 3).toInt());
+    } else {
+        m_scrollLines = 3;
+    }
 }
 
 
@@ -51,5 +65,20 @@ bool Settings::isMobile() const
     return m_mobile;
 }
 
+QString Settings::style() const
+{
+    return m_style;
+}
+
+void Settings::setStyle(const QString &style)
+{
+    m_style = style;
+}
+
+int Settings::mouseWheelScrollLines() const
+{
+    return m_scrollLines;
+}
+
 #include "moc_settings.cpp"
 
